
%global gem_name sensu

Name:           %{gem_name}
Version:        1.1.3
Release:        2%{?dist}
Summary:        A monitoring framework
Group:          Development/Languages
License:        MIT
URL:            https://github.com/sensu/sensu
Source0:        https://rubygems.org/downloads/%{gem_name}-%{version}.gem
Source1:        https://github.com/sensu/sensu/archive/v%{version}.tar.gz#/%{gem_name}-%{version}.tar.gz
Source2:        sensu-api.service
Source3:        sensu-client.service
Source4:        sensu-server.service
Source5:        sensu.sysconfig
Source6:        sensu.logrotate
Source7:        sensu.config
Patch1:         0001-Disable-network-based-tests.patch

BuildRequires:      ruby
BuildRequires:      rubygems-devel
BuildRequires:      systemd
# test suite requirements
BuildRequires:      rubygem(rspec)
BuildRequires:      rubygem(addressable)
BuildRequires:      rubygem(em-http-request) >= 1.1.5
# test suite runtime requirements
BuildRequires:      rubygem(em-http-server) >= 0.1.8
BuildRequires:      rubygem(eventmachine) >= 1.2.5
BuildRequires:      rubygem(sensu-extension) >= 1.5.1
BuildRequires:      rubygem(sensu-extensions) >= 1.9.0
BuildRequires:      rubygem(sensu-json) >= 2.1.0
BuildRequires:      rubygem(sensu-logger) >= 1.2.1
BuildRequires:      rubygem(sensu-redis) >= 2.2.0
BuildRequires:      rubygem(sensu-settings) >= 10.9.0
BuildRequires:      rubygem(sensu-spawn) >= 2.2.1
BuildRequires:      rubygem(sensu-transport) >= 7.0.2

Requires(pre):      shadow-utils
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd
# runtime requirements
Requires:           rubygem(em-http-server) >= 0.1.8
Requires:           rubygem(eventmachine) >= 1.2.5
Requires:           rubygem(sensu-extension) >= 1.5.1
Requires:           rubygem(sensu-extensions) >= 1.9.0
Requires:           rubygem(sensu-json) >= 2.1.0
Requires:           rubygem(sensu-logger) >= 1.2.1
Requires:           rubygem(sensu-redis) >= 2.2.0
Requires:           rubygem(sensu-settings) >= 10.9.0
Requires:           rubygem(sensu-spawn) >= 2.2.1
Requires:           rubygem(sensu-transport) >= 7.0.2

BuildArch: noarch

%description
A monitoring framework that aims to be simple, malleable, and scalable.


%package doc
Summary:        Documentation for %{name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description doc
Documentation for %{name}.

%prep
gem unpack %{SOURCE0}
%if 0%{?dlrn} > 0
%setup -q -D -T -n  %{dlrn_nvr}
%else
%setup -q -D -T -n  %{gem_name}-%{version}
%endif
gem spec %{SOURCE0} -l --ruby > %{gem_name}.gemspec
# relax generated dependencies
sed -i 's#s.add_\(.*\)dependency(\(.*\), \["= \(.*\)"\])#s.add_\1dependency(\2, \["~> \3"\]\)#' %{gem_name}.gemspec

#%patch1 -p1

%build
# Create the gem as gem install only works on a gem file
gem build %{gem_name}.gemspec

# %%gem_install compiles any C extensions and installs the gem into ./%%gem_dir
# by default, so that we can move it into the buildroot in %%install
%gem_install

%install
mkdir -p %{buildroot}%{gem_dir}
cp -a .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

# prepare unit test suite
install -d -p %{_builddir}%{gem_instdir}
%if 0%{?dlrn} > 0
tar -xvzf %{SOURCE1} -C %{_builddir}/%{dlrn_nvr}/%{gem_instdir} --strip-components=1 %{gem_name}-%{version}/spec
%else
tar -xvzf %{SOURCE1} -C %{_builddir}/%{gem_name}-%{version}/%{gem_instdir} --strip-components=1 %{gem_name}-%{version}/spec
%endif

# remove network based tests
pushd %{_builddir}/%{gem_name}-%{version}/%{gem_instdir}
patch -p1 < %{PATCH1}
popd

mkdir -p %{buildroot}%{_bindir}
cp -pa .%{_bindir}/* \
        %{buildroot}%{_bindir}/

find %{buildroot}%{gem_instdir}/exe -type f | xargs chmod a+x

# install systemd service files
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/
install -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/
install -p -m 0644 %{SOURCE4} %{buildroot}%{_unitdir}/
# install sysconfig
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
# install logrotate
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
install -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
# install default config
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/conf.d
install -p -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name}/config.json
# install remaining directory structure and files
mkdir -p %{buildroot}%{_localstatedir}/log/%{name}
touch %{buildroot}%{_localstatedir}/log/%{name}/%{name}-client.log
touch %{buildroot}%{_localstatedir}/log/%{name}/%{name}-server.log
touch %{buildroot}%{_localstatedir}/log/%{name}/%{name}-api.log
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}

%check
pushd .%{gem_instdir}
# TO-DO: Most of the tests are disabled (by Patch1) due to network connection
#        requirement. This should be mocked / fixed in the future
rspec spec
popd

%pre
getent group sensu >/dev/null || groupadd -r sensu
getent passwd sensu >/dev/null || \
    useradd -r -g sensu -d %{_sharedstatedir}/%{name} -s /sbin/nologin \
    -c "Sensu monitoring software" sensu
exit 0

%post
%systemd_post sensu-server.service sensu-client.service sensu-api.service

%preun
%systemd_preun sensu-server.service sensu-client.service sensu-api.service

%postun
%systemd_postun sensu-server.service sensu-client.service sensu-api.service

%files
%dir %{gem_instdir}
%{_bindir}/sensu-server
%{_bindir}/sensu-client
%{_bindir}/sensu-api
%{_bindir}/sensu-install
%{gem_instdir}/exe
%{gem_libdir}
%{_unitdir}/*.service
%{_sysconfdir}/sysconfig/%{name}
%{_sysconfdir}/logrotate.d/%{name}
%attr(0770, sensu, sensu) %{_sysconfdir}/%{name}
%dir %attr(0770, sensu, sensu) %{_localstatedir}/log/%{name}
%attr(0770, sensu, sensu) %{_localstatedir}/log/%{name}/%{name}-client.log
%attr(0770, sensu, sensu) %{_localstatedir}/log/%{name}/%{name}-server.log
%attr(0770, sensu, sensu) %{_localstatedir}/log/%{name}/%{name}-api.log
%attr(0770, sensu, sensu) %{_sharedstatedir}/%{name}
%exclude %{gem_cache}
%{gem_spec}

%files doc
%defattr(0770, sensu, sensu, 0770)
%doc %{gem_docdir}
%doc %{gem_instdir}/CHANGELOG.md
%doc %{gem_instdir}/MIT-LICENSE.txt
%doc %{gem_instdir}/README.md
%doc %{gem_instdir}/%{gem_name}.gemspec
# %{gem_instdir}/spec

%changelog
* Tue Oct 16 2018 Matthias Runge <mrunge@redhat.com> 1.1.3-2
- bump release to rebuild

* Wed Dec 06 2017 Martin Mágr <mmagr@redhat.com> - 1.1.3-1
- Updated to upstream version 1.1.3

* Wed Sep 13 2017 Matthias Runge <mrunge@redhat.com> - 0.27.0-3
- import into CentOS opstools, fix build

* Fri Apr 21 2017 Martin Mágr <mmagr@redhat.com> - 0.27.0-2
- Change ownership of doc files to sensu

* Mon Jan 30 2017 Martin Mágr <mmagr@redhat.com> - 0.27.0-1
- Updated to latest upstream version

* Wed Jan 04 2017 Martin Mágr <mmagr@redhat.com> - 0.27.0.beta.2-2
- Add configuration install back

* Mon Jan 02 2017 Martin Mágr <mmagr@redhat.com> - 0.27.0.beta.2-1
- Updated to latest upstream version
- Fixed log files permissions
- Use own systemd service files, logrotate config and sysconfig

* Fri Aug 12 2016 Martin Mágr <mmagr@redhat.com> - 0.23.2-3
- Relax dependencies so the package works with EPEL packages

* Tue May 31 2016 Martin Mágr <mmagr@redhat.com> - 0.23.2-2
- Changed home directory for user sensu to /var/lib/sensu

* Mon May 09 2016 Martin Mágr <mmagr@redhat.com> - 0.23.2-1
- Updated to upstream version 0.23.2
- Run at least some of the unit tests

* Mon Mar 07 2016 Martin Mágr <mmagr@redhat.com> - 0.22.0-1
- Updated to upstream version 0.22.0

* Thu Jun 18 2015 Graeme Gillies <ggillies@redhat.com> - 0.16.0-2
- Corrected spec file macro so explicit dependencies for EL7 are included

* Fri Jan 23 2015 Graeme Gillies <ggillies@redhat.com> - 0.16.0-1
- Initial package
